@@ -1,4 +1,3 @@
-from . import elastic_2D
-from . import elastic_bulk
 from .elastic_properties import ElasticProperties
-from .structure import Structure
\ No newline at end of file
+from .elastic_properties_2d import ElasticProperties2D
+from .structure import Structure
